Développeurs

Référence API pour les développeurs

Une clé API est requise pour que les requêtes soient traitées par le système. Dès l'inscription d'un utilisateur, une clé API lui est automatiquement générée.

Prise en main

Une clé API est nécessaire pour que les requêtes soient traitées par le système. Dès l'inscription d'un utilisateur, une clé API est générée automatiquement. La clé API doit être envoyée à chaque requête (voir l'exemple complet ci-dessous). Si la clé n'est pas envoyée ou est expirée, une erreur sera renvoyée. Veillez à garder votre clé API secrète pour éviter tout abus.

Authentification

Pour vous authentifier auprès du système API, vous devez envoyer votre clé API comme jeton d'autorisation à chaque requête. Voir l'exemple de code ci-dessous.

curl --location --request POST 'https://g-linkly.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \ 

Limite de débit

Notre API dispose d'un limiteur de débit pour se protéger contre les pics de requêtes et maximiser sa stabilité. Il est actuellement plafonné à 30 requêtes par 1 minute. Veuillez noter que la limite peut varier selon le forfait souscrit.

Plusieurs en-têtes sont envoyés avec la réponse ; vous pouvez les examiner pour obtenir diverses informations sur la requête.

X-RateLimit-Limit: 30X-RateLimit-Remaining: 29X-RateLimit-Reset: TIMESTAMP

Gestion des réponses

Toutes les réponses de l'API sont retournées au format JSON par défaut. Pour les convertir en données exploitables, utilisez la fonction adaptée à votre langage. En PHP, la fonction json_decode() permet de convertir les données en objet (par défaut) ou en tableau (en passant true comme second paramètre). Il est important de vérifier la clé error, qui indique si une erreur s'est produite. Vous pouvez également vérifier le code d'en-tête.

{
    "error": 1,
    "message": "An error occurred"
}

Campagnes

Lister les campagnes

GET https://g-linkly.com/api/campaigns?limit=2&page=1

Pour récupérer vos campagnes via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/campaigns?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "campaigns": [
            {
                "id": 1,
                "name": "Sample Campaign",
                "public": false,
                "rotator": false,
                "list": "https:\/\/domain.com\/u\/admin\/list-1"
            },
            {
                "id": 2,
                "domain": "Facebook Campaign",
                "public": true,
                "rotator": "https:\/\/domain.com\/r\/test",
                "list": "https:\/\/domain.com\/u\/admin\/test-2"
            }
        ]
    }
}

Créer une campagne

POST https://g-linkly.com/api/campaign/add

Une campagne peut être ajoutée via ce endpoint.

Paramètre Description
name (optionnel) Nom de la campagne
slug (optionnel) Slug de rotation
public (optionnel) Accès
curl --location --request POST 'https://g-linkly.com/api/campaign/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Campaign",
    "slug": "new-campaign",
    "public": true
}'

Réponse du serveur

{
    "error": 0,
    "id": 3,
    "domain": "New Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/new-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/new-campaign-3"
}

Associer un lien à une campagne

POST https://g-linkly.com/api/campaign/:campaignid/assign/:linkid

Un lien court peut être associé à une campagne via ce endpoint. Il nécessite l'ID de la campagne et l'ID du lien court.

curl --location --request POST 'https://g-linkly.com/api/campaign/:campaignid/assign/:linkid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "Link successfully added to the campaign."
}

Mettre à jour la campagne

PUT https://g-linkly.com/api/campaign/:id/update

Pour mettre à jour une campagne, envoyez des données valides en JSON via une requête PUT. Les données doivent être envoyées dans le corps brut de la requête, comme illustré ci-dessous. L'exemple montre tous les paramètres possibles, mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'infos).

Paramètre Description
name (requis) Nom de la campagne
slug (optionnel) Slug de rotation
public (optionnel) Accès
curl --location --request PUT 'https://g-linkly.com/api/campaign/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Twitter Campaign",
    "slug": "twitter-campaign",
    "public": true
}'

Réponse du serveur

{
    "error": 0,
    "id": 3,
    "domain": "Twitter Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/twitter-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/twitter-campaign-3"
}

Supprimer la campagne

DELETE https://g-linkly.com/api/campaign/:id/delete

Pour supprimer une campagne, envoyez une requête DELETE.

curl --location --request DELETE 'https://g-linkly.com/api/campaign/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "Campaign has been deleted successfully."
}

Lister les canaux

GET https://g-linkly.com/api/channels?limit=2&page=1

Pour récupérer vos canaux via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/channels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "channels": [
            {
                "id": 1,
                "name": "Channel 1",
                "description": "Description of channel 1",
                "color": "#000000",
                "starred": true
            },
            {
                "id": 2,
                "name": "Channel 2",
                "description": "Description of channel 2",
                "color": "#FF0000",
                "starred": false
            }
        ]
    }
}

Lister les éléments d'un canal

GET https://g-linkly.com/api/channel/:id?limit=1&page=1

Pour récupérer les éléments d'un canal via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/channel/:id?limit=1&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "items": [
            {
                "type": "links",
                "id": 1,
                "title": "My Sample Link",
                "preview": "https:\/\/google.com",
                "link": "https:\/\/g-linkly.com\/google",
                "date": "2022-05-12"
            },
            {
                "type": "bio",
                "id": 1,
                "title": "My Sample Bio",
                "preview": "https:\/\/g-linkly.com\/mybio",
                "link": "https:\/\/g-linkly.com\/mybio",
                "date": "2022-06-01"
            }
        ]
    }
}

Créer un canal

POST https://g-linkly.com/api/channel/add

Un canal peut être ajouté via ce endpoint.

Paramètre Description
name (requis) Nom du canal
description (optionnel) Description du canal
color (optionnel) Couleur du badge du canal (HEX)
starred (optionnel) Épingler le canal ou non (true ou false)
curl --location --request POST 'https://g-linkly.com/api/channel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}'

Réponse du serveur

{
    "error": 0,
    "id": 3,
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}

Associer un élément à un canal

POST https://g-linkly.com/api/channel/:channelid/assign/:type/:itemid

Un élément peut être associé à n'importe quel canal en envoyant une requête avec l'id du canal, le type d'élément (links, bio ou qr) et l'id de l'élément.

Paramètre Description
:channelid (requis) ID du canal
:type (requis) links, bio ou qr
:itemid (requis) ID de l'élément
curl --location --request POST 'https://g-linkly.com/api/channel/:channelid/assign/:type/:itemid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "Item successfully added to the channel."
}

Mettre à jour le canal

PUT https://g-linkly.com/api/channel/:id/update

Pour mettre à jour un canal, envoyez des données valides en JSON via une requête PUT. Les données doivent être envoyées dans le corps brut de la requête, comme illustré ci-dessous. L'exemple montre tous les paramètres possibles, mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'infos).

Paramètre Description
name (optionnel) Nom du canal
description (optionnel) Description du canal
color (optionnel) Couleur du badge du canal (HEX)
starred (optionnel) Épingler le canal ou non (true ou false)
curl --location --request PUT 'https://g-linkly.com/api/channel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Acme Corp",
    "description": "channel for items for Acme Corp",
    "color": "#FFFFFF",
    "starred": false
}'

Réponse du serveur

{
    "error": 0,
    "message": "Channel has been updated successfully."
}

Supprimer le canal

DELETE https://g-linkly.com/api/channel/:id/delete

Pour supprimer un canal, envoyez une requête DELETE. Tous ses éléments seront également dissociés.

curl --location --request DELETE 'https://g-linkly.com/api/channel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "Channel has been deleted successfully."
}

Obtenir le compte

GET https://g-linkly.com/api/account

Pour obtenir des informations sur le compte, envoyez une requête à ce endpoint ; il retournera les données du compte.

curl --location --request GET 'https://g-linkly.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "data": {
        "id": 1,
        "email": "sample@domain.com",
        "username": "sampleuser",
        "avatar": "https:\/\/domain.com\/content\/avatar.png",
        "status": "pro",
        "expires": "2022-11-15 15:00:00",
        "registered": "2020-11-10 18:01:43"
    }
}

Mettre à jour le compte

PUT https://g-linkly.com/api/account/update

Pour mettre à jour les informations du compte, envoyez une requête à ce endpoint ; il mettra à jour les données du compte.

curl --location --request PUT 'https://g-linkly.com/api/account/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "email": "newemail@google.com",
    "password": "NewPassword1"
}'

Réponse du serveur

{
    "error": 0,
    "message": "Account has been successfully updated."
}

Domaines personnalisés

Lister les domaines personnalisés

GET https://g-linkly.com/api/domains?limit=2&page=1

Pour récupérer vos domaines personnalisés via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/domains?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "domains": [
            {
                "id": 1,
                "domain": "https:\/\/domain1.com",
                "redirectroot": "https:\/\/rootdomain.com",
                "redirect404": "https:\/\/rootdomain.com\/404"
            },
            {
                "id": 2,
                "domain": "https:\/\/domain2.com",
                "redirectroot": "https:\/\/rootdomain2.com",
                "redirect404": "https:\/\/rootdomain2.com\/404"
            }
        ]
    }
}

Créer un domaine personnalisé

POST https://g-linkly.com/api/domain/add

Un domaine peut être ajouté via ce endpoint. Assurez-vous que le domaine pointe correctement vers notre serveur.

Paramètre Description
domain (requis) Domaine personnalisé incluant http ou https
redirectroot (optionnel) Redirection racine lorsqu'un visiteur accède à votre domaine
redirect404 (optionnel) Redirection 404 personnalisée
curl --location --request POST 'https://g-linkly.com/api/domain/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "domain": "https:\/\/domain1.com",
    "redirectroot": "https:\/\/rootdomain.com",
    "redirect404": "https:\/\/rootdomain.com\/404"
}'

Réponse du serveur

{
    "error": 0,
    "id": 1
}

Mettre à jour le domaine

PUT https://g-linkly.com/api/domain/:id/update

Pour mettre à jour un domaine personnalisé, envoyez des données valides en JSON via une requête PUT. Les données doivent être envoyées dans le corps brut de la requête, comme illustré ci-dessous. L'exemple montre tous les paramètres possibles, mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'infos).

Paramètre Description
redirectroot (optionnel) Redirection racine lorsqu'un visiteur accède à votre domaine
redirect404 (optionnel) Redirection 404 personnalisée
curl --location --request PUT 'https://g-linkly.com/api/domain/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "redirectroot": "https:\/\/rootdomain-new.com",
    "redirect404": "https:\/\/rootdomain-new.com\/404"
}'

Réponse du serveur

{
    "error": 0,
    "message": "Domain has been updated successfully."
}

Supprimer un domaine

DELETE https://g-linkly.com/api/domain/:id/delete

Pour supprimer un domaine, envoyez une requête DELETE.

curl --location --request DELETE 'https://g-linkly.com/api/domain/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "Domain has been deleted successfully."
}

Page de transition personnalisée

Lister les pages d'interstitiel

GET https://g-linkly.com/api/splash?limit=2&page=1

Pour récupérer les pages d'interstitiel via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/splash?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "splash": [
            {
                "id": 1,
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "name": "Product 2 Promo",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Lister les pixels

GET https://g-linkly.com/api/pixels?limit=2&page=1

Pour récupérer vos codes de pixel via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/pixels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "pixels": [
            {
                "id": 1,
                "type": "gtmpixel",
                "name": "GTM Pixel",
                "tag": "GA-123456789",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "twitterpixel",
                "name": "Twitter Pixel",
                "tag": "1234567",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Créer un pixel

POST https://g-linkly.com/api/pixel/add

Un pixel peut être créé via ce endpoint. Vous devez envoyer le type de pixel et le tag.

Paramètre Description
type (required) gtmpixel | gapixel | fbpixel | adwordspixel | linkedinpixel | twitterpixel | adrollpixel | quorapixel | pinterest | bing | snapchat | reddit | tiktok
name (requis) Nom personnalisé pour votre pixel
tag (requis) Le tag du pixel
curl --location --request POST 'https://g-linkly.com/api/pixel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "gtmpixel",
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Réponse du serveur

{
    "error": 0,
    "id": 1
}

Mettre à jour le pixel

PUT https://g-linkly.com/api/pixel/:id/update

Pour mettre à jour un pixel, envoyez des données valides en JSON via une requête PUT. Les données doivent être envoyées dans le corps brut de la requête, comme illustré ci-dessous. L'exemple montre tous les paramètres possibles, mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'infos).

Paramètre Description
name (optionnel) Nom personnalisé pour votre pixel
tag (requis) Le tag du pixel
curl --location --request PUT 'https://g-linkly.com/api/pixel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Réponse du serveur

{
    "error": 0,
    "message": "Pixel has been updated successfully."
}

Supprimer un pixel

DELETE https://g-linkly.com/api/pixel/:id/delete

Pour supprimer un pixel, envoyez une requête DELETE.

curl --location --request DELETE 'https://g-linkly.com/api/pixel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "Pixel has been deleted successfully."
}

QR Codes

Lister les QR codes

GET https://g-linkly.com/api/qr?limit=2&page=1

Pour récupérer vos QR codes via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/qr?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "qrs": [
            {
                "id": 2,
                "link": "https:\/\/g-linkly.com\/qr\/a2d5e",
                "scans": 0,
                "name": "Google",
                "date": "2020-11-10 18:01:43"
            },
            {
                "id": 1,
                "link": "https:\/\/g-linkly.com\/qr\/b9edfe",
                "scans": 5,
                "name": "Google Canada",
                "date": "2020-11-10 18:00:25"
            }
        ]
    }
}

Obtenir un QR code

GET https://g-linkly.com/api/qr/:id

Pour obtenir les détails d'un QR code via l'API, utilisez ce endpoint.

curl --location --request GET 'https://g-linkly.com/api/qr/:id' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "details": {
        "id": 1,
        "link": "https:\/\/g-linkly.com\/qr\/b9edfe",
        "scans": 5,
        "name": "Google Canada",
        "date": "2020-11-10 18:00:25"
    },
    "data": {
        "clicks": 1,
        "uniqueClicks": 1,
        "topCountries": {
            "Unknown": "1"
        },
        "topReferrers": {
            "Direct, email and other": "1"
        },
        "topBrowsers": {
            "Chrome": "1"
        },
        "topOs": {
            "Windows 10": "1"
        },
        "socialCount": {
            "facebook": 0,
            "twitter": 0,
            "instagram": 0
        }
    }
}

Créer un QR code

POST https://g-linkly.com/api/qr/add

Pour créer un QR code, envoyez des données valides en JSON via une requête POST. Les données doivent être envoyées dans le corps brut de la requête, comme illustré ci-dessous. L'exemple montre tous les paramètres possibles, mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'infos).

Paramètre Description
type (requis) text | vcard | link | email | phone | sms | wifi
data (requis) Données à intégrer dans le QR code. Les données peuvent être une chaîne ou un tableau selon le type
background (optionnel) Couleur RGB, ex. rgb(255,255,255)
foreground (optionnel) Couleur RGB, ex. rgb(0,0,0)
logo (optionnel) Chemin vers le logo, au format png ou jpg
name (optionnel) Nom du QR code
curl --location --request POST 'https://g-linkly.com/api/qr/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png",
    "name": "QR Code API"
}'

Réponse du serveur

{
    "error": 0,
    "id": 3,
    "link": "https:\/\/g-linkly.com\/qr\/a58f79"
}

Mettre à jour le QR code

PUT https://g-linkly.com/api/qr/:id/update

Pour mettre à jour un QR code, envoyez des données valides en JSON via une requête PUT. Les données doivent être envoyées dans le corps brut de la requête, comme illustré ci-dessous. L'exemple montre tous les paramètres possibles, mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'infos).

Paramètre Description
data (requis) Données à intégrer dans le QR code. Les données peuvent être une chaîne ou un tableau selon le type
background (optionnel) Couleur RGB, ex. rgb(255,255,255)
foreground (optionnel) Couleur RGB, ex. rgb(0,0,0)
logo (optionnel) Chemin vers le logo, au format png ou jpg
curl --location --request PUT 'https://g-linkly.com/api/qr/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png"
}'

Réponse du serveur

{
    "error": 0,
    "message": "QR has been updated successfully."
}

Supprimer un QR code

DELETE https://g-linkly.com/api/qr/:id/delete

Pour supprimer un QR code, envoyez une requête DELETE.

curl --location --request DELETE 'https://g-linkly.com/api/qr/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": 0,
    "message": "QR Code has been deleted successfully."
}

Superpositions CTA

Lister les overlays CTA

GET https://g-linkly.com/api/overlay?limit=2&page=1

Pour récupérer les overlays CTA via l'API, utilisez ce endpoint. Vous pouvez aussi filtrer les données (voir le tableau pour plus d'infos).

Paramètre Description
limit (optionnel) Nombre de résultats par page
page (optionnel) Page actuelle de la requête
curl --location --request GET 'https://g-linkly.com/api/overlay?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Réponse du serveur

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "cta": [
            {
                "id": 1,
                "type": "message",
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "contact",
                "name": "Contact Page",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}